fix an issue with "lost" dependencies in project model when more than one KLIB is included into project's library
diff --git a/idea/idea-native/src/org/jetbrains/konan/analyser/KonanAnalyzerFacade.kt b/idea/idea-native/src/org/jetbrains/konan/analyser/KonanAnalyzerFacade.kt
index 2606976..ed80c33 100644
--- a/idea/idea-native/src/org/jetbrains/konan/analyser/KonanAnalyzerFacade.kt
+++ b/idea/idea-native/src/org/jetbrains/konan/analyser/KonanAnalyzerFacade.kt
@@ -73,9 +73,9 @@
 
             val libraryInfo = LibraryInfo(project, library)
 
             // "single" because any KLIB should have just one root
             // "null" just for the case when KLIB accidentally disappeared from the expected location
-            val libraryPath = libraryInfo.getLibraryRoots().singleOrNull()
+            val libraryPath = libraryInfo.getLibraryRoots().firstOrNull()
             val virtualFile = libraryPath?.let { LocalFileSystem.getInstance().refreshAndFindFileByIoFile(File(it)) }
 
             return if (virtualFile != null && virtualFile.exists()) {
@@ -73,9 +73,9 @@
             val libraryInfo = LibraryInfo(project, library)
 
-            // "single" because any KLIB should have just one root
+            // "first" because normally any KLIB should have just one root
             // "null" just for the case when KLIB accidentally disappeared from the expected location